@@ -35,7 +35,7 @@ from .generated.metadatagen import MetadataGenClientV1
 from .metadata import MetadataClientV2, MetadataClientV3
 from .base import constants
 from azure.storage.blob import BlobClient
-from .commonmodels import PropertyDefinition, ItemId, UnitId, SpatialFilter, TemporalFilter, VerticalFilter
+from .commonmodels import PropertyDefinition, ItemId, TemporalValueFilter, UnitId, SpatialFilter, TemporalFilter, VerticalFilter
 
 
 class ParameterDefinition:
@@ -1003,6 +1003,15 @@ class GenericReader(TransferReaderBase):
         return super()._with_allowed_items_impl(allowed_items)
 
 
+class MDReader(TransferReaderBase):
+    def __init__(self, parameters:Tuple = ()) -> None:
+        super().__init__(parameters=parameters)
+    
+    @property
+    def name(self):
+        return "MDReader"
+
+
 class DfsuReader(TransferReaderBase):
     def __init__(self, parameters: Tuple = ()) -> None:
         super().__init__(parameters=parameters)
@@ -1640,7 +1649,7 @@ class TransferProcessInvoker:
             writer_name = writer_name,
             reader_parameters = reader_parameters,
             writer_parameters = writer_parameters,
-            transformations=process.transformations
+            transformations=transfer_pipeline.transformations
         )
 
 
